@@ -33,6 +33,8 @@ MODEL_INPUTS_ROOT = Path('/ihme/covid-19/model-inputs/')
 VISIT_VOLUME_ROOT = Path('/ihme/covid-19/visit-volume/')
 MORTALITY_RATIO_ROOT = Path('/ihme/covid-19/mortality-ratio')
 INFECTION_FATALITY_RATIO_ROOT = Path('/ihme/covid-19/infection-fatality-ratio')
+INFECTION_HOSPITALIZATION_RATIO_ROOT = Path('/ihme/covid-19/infection-hospitalization-ratio')
+INFECTION_DETECTION_RATE_ROOT = Path('/ihme/covid-19/infection-detection-rate')
 HOSPITAL_DEATH_RATIO_ROOT = Path('/ihme/covid-19/hospitalization-death-ratio')
 DEATHS_SPLINE_OUTPUT_ROOT = Path('/ihme/covid-19/deaths-outputs/')
 PAST_INFECTIONS_ROOT = Path('/ihme/covid-19/past-infections')
